@@ -253,6 +253,7 @@ class ExplainerDashboard:
                  url_base_pathname=None,
                  responsive=True,
                  logins=None,
+                 port=8050,
                  importances=True,
                  model_summary=True,
                  contributions=True,
@@ -339,12 +340,29 @@ class ExplainerDashboard:
         if hide_header:
             header_hide_title = True
             header_hide_selector = True
+        self.explainer = explainer
         self.mode, self.width, self.height = mode, width, height
         self.hide_header, self.header_hide_title, self.header_hide_selector = \
             hide_header, header_hide_title, header_hide_selector
         self.external_stylesheets = external_stylesheets
         self.server, self.url_base_pathname = server, url_base_pathname
-        self.responsive = responsive
+        self.responsive, self.port = responsive, port
+        self._params_dict = dict(
+                tabs=self._tabs_to_param(tabs),
+                title=title, hide_header=hide_header, 
+                header_hide_title=header_hide_title,
+                header_hide_selector=header_hide_selector,
+                block_selector_callbacks=block_selector_callbacks,
+                pos_label=pos_label, fluid=fluid, mode=mode,
+                width=width, height=height, 
+                external_stylesheets=external_stylesheets, server=server,
+                url_base_pathname=url_base_pathname, responsive=responsive,
+                logins=logins, port=port, importances=importances,
+                model_summary=model_summary, contributions=contributions,
+                whatif=whatif, shap_dependence=shap_dependence,
+                shap_interaction=shap_interaction, 
+                decision_trees=decision_trees
+        )
 
         try:
             ipython_kernel = str(get_ipython())
@@ -438,6 +456,18 @@ class ExplainerDashboard:
                 return  DecisionTreesTab
         return component
 
+    @staticmethod
+    def _tabs_to_param(tabs):
+        """converts tabs to a yaml friendly format"""
+        if tabs is None:
+            return None
+        
+        if not hasattr(tabs, "__iter__"):
+            return tabs if isinstance(tabs, str) else dict(tab=tabs.__name__, module=tabs.__module__)
+            
+        return [tab if isinstance(tab, str) else dict(tab=tab.__name__, module=tab.__module__) for tab in tabs]
+
+
     def _get_dash_app(self):
         if self.responsive:
             meta_tags = [{'name': 'viewport', 'content': 'width=device-width, initial-scale=1.0, maximum-scale=1.2, minimum-scale=0.5,'}]
@@ -479,11 +509,12 @@ class ExplainerDashboard:
             print("Warning: in production you should probably use mode='dash'...")
         return self.app.server
         
-    def run(self, port=8050, **kwargs):
+    def run(self, port=None, **kwargs):
         """Start ExplainerDashboard on port
 
         Args:
-            port (int, optional): port to run on. Defaults to 8050.
+            port (int, optional): port to run on. If None, then use self.port.
+            Defaults to None.self.port defaults to 8050.
 
         Raises:
             ValueError: if mode is unknown
@@ -491,13 +522,15 @@ class ExplainerDashboard:
         """
 
         pio.templates.default = "none"
-        self.port = port
+        if port is None:
+            port = self.port
         
         if self.mode == 'dash':
             print(f"Starting ExplainerDashboard on http://localhost:{port}", flush=True)
             self.app.run_server(port=port, **kwargs)
         elif self.mode == 'external':
-            print(f"Starting ExplainerDashboard on http://localhost:{port}", flush=True)
+            if not self.is_colab:
+                print(f"Starting ExplainerDashboard on http://localhost:{port}", flush=True)
             self.app.run_server(port=port, mode=self.mode, **kwargs)
         elif self.mode in ['inline', 'jupyterlab']:
             self.app.run_server(port=port, mode=self.mode, 
@@ -538,22 +571,33 @@ class ExplainerDashboard:
         except Exception as e:
             print(f"Something seems to have failed: {e}")
 
+    def to_yaml(self, filepath=None, return_dict=False):
+        """Returns a yaml configuration of the current ExplainerDashboard
+        that can be used by the explainerdashboard CLI.
 
-class JupyterExplainerDashboard(ExplainerDashboard):
-    def __init__(self, *args, **kwargs):
-        raise ValueError("JupyterExplainerDashboard has been deprecated. "
-                    "Use e.g. ExplainerDashboard(mode='inline') instead.")
+        Args:
+            filepath ({str, Path}, optional): Filepath to dump yaml. If None
+                returns the yaml as a string. Defaults to None.
+            return_dict (bool, optional): instead of yaml return dict with 
+                config.
+        """
+        import oyaml as yaml
 
-class ExplainerTab:
-    def __init__(self, *args, **kwargs):
-        raise ValueError("ExplainerTab has been deprecated. "
-                        "Use e.g. ExplainerDashboard(explainer, ImportancesTab) instead.")
+        explainer_config = self.explainer.to_yaml(return_dict=True)
+        dashboard_config = dict(
+            dashboard=dict(
+                explainerfile="explainer.joblib",
+                params=self._params_dict))
+        yaml_config = {**explainer_config, **dashboard_config}
 
+        if return_dict:
+            return yaml_config
+        
+        if filepath is not None:
+            yaml.dump(yaml_config, open(filepath, "w"))
+            return
+        return yaml.dump(yaml_config)
 
-class JupyterExplainerTab(ExplainerTab):
-    def __init__(self, *args, **kwargs):
-        raise ValueError("ExplainerTab has been deprecated. "
-                        "Use e.g. ExplainerDashboard(explainer, ImportancesTab, mode='inline') instead.")
 
 
 class InlineExplainer:
@@ -674,6 +718,13 @@ class InlineExplainer:
         comp = PdpComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
+    @delegates_kwargs(WhatIfComponent)
+    @delegates_doc(WhatIfComponent)
+    def whatif(self, title="What if...", **kwargs):
+        """Show What if... component inline in notebook"""
+        comp = WhatIfComponent(self._explainer, **kwargs)
+        self._run_component(comp, title)
+
     
 class InlineExplainerComponent:
     def __init__(self, inline_explainer, name):
@@ -713,6 +764,13 @@ class InlineExplainerTabs(InlineExplainerComponent):
         """Show contributions (permutation or shap) inline in notebook"""
         tab = ContributionsTab(self._explainer, **kwargs)
         self._run_component(tab, title)
+    
+    @delegates_kwargs(WhatIfTab)
+    @delegates_doc(WhatIfTab)
+    def whatif(self,  title='What if...', **kwargs):
+        """Show What if... tab inline in notebook"""
+        tab = WhatIfTab(self._explainer, **kwargs)
+        self._run_component(tab, title)
 
     @delegates_kwargs(ShapDependenceTab)
     @delegates_doc(ShapDependenceTab)
@@ -812,6 +870,14 @@ class InlineClassifierExplainer(InlineExplainerComponent):
         comp = PrecisionComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
+    @delegates_kwargs(CumulativePrecisionComponent)
+    @delegates_doc(CumulativePrecisionComponent)
+    def cumulative_precision(self, title="Cumulative Precision Plot", **kwargs):
+        """shows cumulative precision plot"""
+        assert self._explainer.is_classifier
+        comp = CumulativePrecisionComponent(self._explainer, **kwargs)
+        self._run_component(comp, title)
+
     @delegates_kwargs(ConfusionMatrixComponent)
     @delegates_doc(ConfusionMatrixComponent)
     def confusion_matrix(self, title="Confusion Matrix", **kwargs):
@@ -915,5 +981,23 @@ class InlineDecisionTreesExplainer(InlineExplainerComponent):
         comp = DecisionPathTableComponent(self._explainer, **kwargs)
         self._run_component(comp, title)
 
+
+
+class JupyterExplainerDashboard(ExplainerDashboard):
+    def __init__(self, *args, **kwargs):
+        raise ValueError("JupyterExplainerDashboard has been deprecated. "
+                    "Use e.g. ExplainerDashboard(mode='inline') instead.")
+
+class ExplainerTab:
+    def __init__(self, *args, **kwargs):
+        raise ValueError("ExplainerTab has been deprecated. "
+                        "Use e.g. ExplainerDashboard(explainer, ImportancesTab) instead.")
+
+
+class JupyterExplainerTab(ExplainerTab):
+    def __init__(self, *args, **kwargs):
+        raise ValueError("ExplainerTab has been deprecated. "
+                        "Use e.g. ExplainerDashboard(explainer, ImportancesTab, mode='inline') instead.")
+
    
 
